@@ -4,8 +4,9 @@
 
 QString FeedEntry::getBody() const
 {
-    if (m_bodyfile.length() == 0)
+    if (m_bodyfile.length() == 0) {
         return m_body;
+    }
 
     QFile f(m_bodyfile);
     f.open(QIODevice::ReadOnly);
@@ -14,7 +15,6 @@ QString FeedEntry::getBody() const
     return res;
 }
 
-
 void FeedEntry::setBodyString(QString body)
 {
     m_body = body;
@@ -26,7 +26,6 @@ void FeedEntry::setBodyFile(QString fname)
     m_bodyfile = fname;
 }
 
-
 IFeedBundle::~IFeedBundle()
 {
 }
