@@ -2,20 +2,18 @@
 #include <QFile>
 #include <QFileInfo>
 
-
-
 bool FilesystemFeedBundle::addPath(const QString& path)
 {
     QFileInfo fi(path);
-    if (!fi.exists() || fi.isDir())
+    if (!fi.exists() || fi.isDir()) {
         return false;
+    }
 
     FilesystemFeed* fsf = new FilesystemFeed;
     fsf->setName(fi.fileName());
     fsf->setFileName(fi.absoluteFilePath());
     m_feeds.append(fsf);
     return true;
-
 }
 
 FilesystemFeedBundle::FilesystemFeedBundle()
@@ -26,20 +24,16 @@ FilesystemFeedBundle::~FilesystemFeedBundle()
 {
 }
 
-
 void FilesystemFeedBundle::getFeeds(QVector< IFeed* >& feeds)
 {
-    foreach( IFeed* feed, m_feeds)
-    {
+    foreach( IFeed* feed, m_feeds) {
         feeds.append(feed);
     }
-
 }
 
 // Feed *************
 
-FilesystemFeed::FilesystemFeed()
-{}
+FilesystemFeed::FilesystemFeed() {}
 
 void FilesystemFeed::getEntries( QVector<FeedEntry>& entries) const
 {
@@ -47,17 +41,12 @@ void FilesystemFeed::getEntries( QVector<FeedEntry>& entries) const
     FeedEntry fe;    
     fe.setBodyFile(m_filename);
 
-    if (m_filename.toLower().endsWith(".htm") || m_filename.toLower().endsWith(".html"))
-    {
+    if (m_filename.toLower().endsWith(".htm") || m_filename.toLower().endsWith(".html")) {
         fe.m_contenttype = "text/html";
-    }
-    else
-    {
+    } else {
         fe.m_contenttype = "text/plain";
     }
-
     entries.append(fe);
-
 }
 
 void FilesystemFeed::setName(const QString& name)
@@ -73,5 +62,5 @@ QString FilesystemFeed::name() const
 void FilesystemFeed::setFileName(const QString& fname)
 {
     m_filename = fname;
-};
+}
 
