@@ -8,7 +8,8 @@ namespace Ui {
     class FingerButtonDialog;
 }
 
-class FingerButtonDialog : public QDialog {
+class FingerButtonDialog : public QDialog
+{
     Q_OBJECT
 public:
     FingerButtonDialog(QWidget *parent = 0);
@@ -18,6 +19,7 @@ public:
     QWidget* widgetAt(int i);
 
     int selectedIndex() const;
+
 private slots:
     void clicked(int buttonindex);
 
@@ -27,9 +29,7 @@ protected:
 private:
     int m_selection;
     Ui::FingerButtonDialog *m_ui;
-
     QVector<QWidget*> m_widgets;
-
     QSignalMapper* m_signalMapper;
 };
 
