@@ -13,7 +13,6 @@ class PenguinTvFeedBundle;
 class IFeedBundle;
 class FeedRenderer;
 
-//! [0]
 class MainWindow : public QMainWindow, public PrAppServices
 {
     Q_OBJECT
@@ -23,21 +22,13 @@ public:
     ~MainWindow();
 
     // from PrAppServices
-
     QSettings* settings();
     void launchUrl(const QUrl& url);
 
-
-
-protected:
-    //void closeEvent(QCloseEvent *event);
-
 private slots:
-
     void zoomInPressed();
     void zoomOutPressed();
 
-
     // PenguinTV stuff
     void setupPenguinTvFeeds();
     void doReadDatabase();
@@ -59,7 +50,7 @@ private:
     QAction *aboutQtAct;
     QAction *helpAct;
 
-    PrTopStackedWidget* m_topWdg;
+    PrTopStackedWidget* m_topWidget;
     IFeedBundle* m_feedBundle;
     FeedRenderer* m_renderer;
     QSettings* m_settings;
