@@ -15,18 +15,20 @@ public:
     void getEntries( QVector<FeedEntry>& entries) const;
     QString name() const;
 
+    void decorate(QListWidgetItem*) const;
+
     // others
     void setName(const QString& name);
 
     int m_feedid;
+    int m_newatlast;
+
     PenguinTvFeedBundle* m_feedbundle;
+
 private:
-
     QString m_name;
-
 };
 
-
 class PenguinTvFeedBundle : public IFeedBundle
 {
 public:
@@ -36,13 +38,11 @@ public:
     void getFeeds(QVector< IFeed* >& feeds);
 
     bool readDatabase();
-    QSqlDatabase& db() { return m_db; };
+    QSqlDatabase& db() { return m_db; }
 
 private:
     QSqlDatabase m_db;
-
     QVector<PenguinTvFeed*> m_feeds;
-
 };
 
 #endif // PENGUINTVFEEDBUNDLE_H
