@@ -28,10 +28,10 @@ public:
     void setFeedBundle(IFeedBundle* feeds);
     void setRenderer(FeedRenderer* renderer);
 
-    FeedRenderer* renderer() { return m_renderer; };
+    FeedRenderer* renderer() { return m_renderer; }
 
-    PrTextBody* bodyWdg();
-    PrFeedView* feedWdg();
+    PrTextBody* bodyWidget();
+    PrFeedView* feedWidget();
     QStringList urlList();
     bool linksEnabled();
 
@@ -55,7 +55,6 @@ private:
     FeedRenderer* m_renderer;
     QListWidgetItem* m_currentItem;
     QStringList m_urlList;
-    //Ui::PrTopStackedWidget *m_ui;
     bool m_linksEnabled;
 };
 
